'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactNative = require('react-native');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var styles = _reactNative.StyleSheet.create({
    wrap: {
        flex: 1,
        backgroundColor: 'rgba(0,0,0,0)'
    },
    mask: {
        backgroundColor: 'black',
        opacity: .5
    },
    content: {
        backgroundColor: 'white'
    },
    absolute: {
        position: 'absolute',
        top: 0,
        bottom: 0,
        left: 0,
        right: 0
    }
});
var screen = _reactNative.Dimensions.get('window');
var RCModal = _react2["default"].createClass({
    displayName: 'RCModal',
    getDefaultProps: function getDefaultProps() {
        return {
            wrapStyle: styles.wrap,
            maskStyle: styles.mask,
            entry: 'bottom',
            animateAppear: false,
            animationDuration: 300,
            visible: false,
            onClose: function onClose() {},
            onAnimationEnd: function onAnimationEnd(visible) {}
        };
    },
    getInitialState: function getInitialState() {
        var visible = this.props.visible;

        return {
            position: new _reactNative.Animated.Value(this.getPosition(visible)),
            maskOpacity: new _reactNative.Animated.Value(this.getMaskOpacity(visible)),
            modalVisible: visible
        };
    },
    componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
        if (this.shouldComponentUpdate(nextProps)) {
            this.setState({
                modalVisible: true
            });
        }
    },
    shouldComponentUpdate: function shouldComponentUpdate(nextProps, nextState) {
        if (this.props.visible || this.props.visible !== nextProps.visible) {
            return true;
        }
        if (nextState) {
            if (nextState.modalVisible !== this.state.modalVisible) {
                return true;
            }
        }
        return false;
    },
    componentDidMount: function componentDidMount() {
        if (this.props.animateAppear) {
            this.componentDidUpdate({});
        }
    },
    componentDidUpdate: function componentDidUpdate(prevProps) {
        var props = this.props;

        if (prevProps.visible !== props.visible) {
            this.animateDialog(props.visible);
        }
    },
    animateMask: function animateMask(visible) {
        var _this = this;

        this.stopMaskAnim();
        this.state.maskOpacity.setValue(this.getMaskOpacity(!visible));
        this.animMask = _reactNative.Animated.timing(this.state.maskOpacity, {
            toValue: this.getMaskOpacity(visible),
            duration: this.props.animationDuration
        });
        this.animMask.start(function () {
            _this.animMask = null;
        });
    },
    stopMaskAnim: function stopMaskAnim() {
        if (this.animMask) {
            this.animMask.stop();
            this.animMask = null;
        }
    },
    stopDialogAnim: function stopDialogAnim() {
        if (this.animDialog) {
            this.animDialog.stop();
            this.animDialog = null;
        }
    },
    animateDialog: function animateDialog(visible) {
        var _this2 = this;

        this.stopDialogAnim();
        this.animateMask(visible);
        this.state.position.setValue(this.getPosition(!visible));
        this.animDialog = _reactNative.Animated.timing(this.state.position, {
            toValue: this.getPosition(visible),
            duration: this.props.animationDuration,
            easing: visible ? _reactNative.Easing.elastic(0.8) : undefined
        });
        this.animDialog.start(function () {
            _this2.animDialog = null;
            if (!visible) {
                _this2.setState({
                    modalVisible: false
                });
            }
            _this2.props.onAnimationEnd(visible);
        });
    },
    close: function close() {
        this.animateDialog(false);
    },
    getPosition: function getPosition(visible) {
        if (visible) {
            return 0;
        }
        return this.props.entry === 'top' ? -screen.height : screen.height;
    },
    getMaskOpacity: function getMaskOpacity(visible) {
        return visible ? 1 : 0;
    },
    render: function render() {
        var props = this.props;

        if (!this.state.modalVisible) {
            return null;
        }
        return _react2["default"].createElement(
            _reactNative.Modal,
            { visible: true, transparent: true, onRequestClose: this.props.onClose },
            _react2["default"].createElement(
                _reactNative.View,
                { style: [styles.wrap, props.wrapStyle] },
                _react2["default"].createElement(
                    _reactNative.TouchableWithoutFeedback,
                    { onPress: this.props.onClose },
                    _react2["default"].createElement(
                        _reactNative.Animated.View,
                        { style: [styles.absolute, { opacity: this.state.maskOpacity }] },
                        _react2["default"].createElement(_reactNative.View, { style: [styles.absolute, props.maskStyle] })
                    )
                ),
                _react2["default"].createElement(
                    _reactNative.Animated.View,
                    { style: [styles.content, props.style, { transform: [{ translateY: this.state.position }] }] },
                    this.props.children
                )
            )
        );
    }
});
exports["default"] = RCModal;
module.exports = exports['default'];